@@ -1,4 +1,4 @@
-//$Id: derivedwindow.h,v 1.1 2002/11/05 13:51:39 murrayc Exp $ -*- c++ -*-
+//$Id: main.cc 1099 2007-09-27 15:23:49Z arminb $ -*- c++ -*-
 
 /* libglademm example Copyright (C) 2003 libglademm development team
  *
@@ -25,6 +25,7 @@ int main (int argc, char **argv)
 
   //Load the Glade file and instiate its widgets:
   Glib::RefPtr<Gnome::Glade::Xml> refXml;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     refXml = Gnome::Glade::Xml::create("basic.glade");
@@ -34,6 +35,15 @@ int main (int argc, char **argv)
     std::cerr << ex.what() << std::endl;
     return 1;
   }
+#else
+  std::auto_ptr<Gnome::Glade::XmlError> error;
+  refXml = Gnome::Glade::Xml::create("basic.glade", "", "", error);
+  if(error.get())
+  {
+    std::cerr << error->what() << std::endl;
+    return 1;
+  }
+#endif
 
   //Get the Glade-instantiated dialog::
   DerivedDialog* pDialog = 0;
@@ -45,6 +55,8 @@ int main (int argc, char **argv)
     //Start:
     kit.run(*pDialog);
   }
+
+  delete pDialog;
     
 
   return 0;
